pub struct BlockAccountant { /* private fields */ }Expand description
Keeps track of downloaded data on per-block basis.
Implementations
Sourceimpl BlockAccountant
impl BlockAccountant
pub fn new(pieces: Rc<PieceInfo>) -> Self
Sourcepub fn submit_block(&mut self, block_info: &BlockInfo) -> Result<usize, Error>
pub fn submit_block(&mut self, block_info: &BlockInfo) -> Result<usize, Error>
Try to add a received block to the internal records. Fails if the block has invalid offset, index or length.
Sourcepub fn submit_piece(&mut self, piece_index: usize) -> bool
pub fn submit_piece(&mut self, piece_index: usize) -> bool
Mark a piece as downloaded. Fails if the piece index is invalid.
Sourcepub fn submit_bitfield(&mut self, bitfield: &Bitfield) -> bool
pub fn submit_bitfield(&mut self, bitfield: &Bitfield) -> bool
Update internal records from a bitfield. All pieces present in the bitfield will be marked as downloaded. Fails if the bitfield has unexpected length.
Sourcepub fn remove_piece(&mut self, piece_index: usize)
pub fn remove_piece(&mut self, piece_index: usize)
Remove a piece from the internal records, i.e. no longer consider it as downloaded.
Sourcepub fn has_exact_block_at(&self, global_offset: usize, length: usize) -> bool
pub fn has_exact_block_at(&self, global_offset: usize, length: usize) -> bool
Check whether length bytes at global_offset have been downloaded.
Sourcepub fn has_exact_block(&self, block_info: &BlockInfo) -> bool
pub fn has_exact_block(&self, block_info: &BlockInfo) -> bool
Check presense of an exact block among the downloaded data.
Sourcepub fn has_piece(&self, piece_index: usize) -> bool
pub fn has_piece(&self, piece_index: usize) -> bool
Check whether the piece at piece_index has been downloaded.
Sourcepub fn generate_bitfield(&self) -> Bitfield
pub fn generate_bitfield(&self) -> Bitfield
Represent the internal state as a bitfield. Partially downloaded pieces won’t be included.
Sourcepub fn accounted_bytes(&self) -> usize
pub fn accounted_bytes(&self) -> usize
The total number of downloaded bytes.
Sourcepub fn missing_bytes(&self) -> usize
pub fn missing_bytes(&self) -> usize
The total number of missing bytes.