pub struct PendingRequests { /* private fields */ }Expand description
Keeps track of outstanding requests with piece-level granularity (as opposed to blocks).
Implementations
Sourceimpl PendingRequests
impl PendingRequests
Sourcepub fn add(&mut self, piece: usize, peer: &SocketAddr)
pub fn add(&mut self, piece: usize, peer: &SocketAddr)
Add a record of a new request sent to peer asking for the piece index piece.
Sourcepub fn clear_requests_of(&mut self, piece: usize)
pub fn clear_requests_of(&mut self, piece: usize)
Forget all pending requests asking peers for the piece index piece.
Sourcepub fn clear_requests_to(&mut self, peer: &SocketAddr)
pub fn clear_requests_to(&mut self, peer: &SocketAddr)
Forget all pending requests sent to peer.
Sourcepub fn is_piece_requested(&self, piece: usize) -> bool
pub fn is_piece_requested(&self, piece: usize) -> bool
Check presense of any pending requests asking for the piece index piece.
Sourcepub fn is_piece_requested_from(&self, peer: &SocketAddr, piece: usize) -> bool
pub fn is_piece_requested_from(&self, peer: &SocketAddr, piece: usize) -> bool
Check if a request asking for the piece index piece has been sent to peer.
Sourcepub fn requests_in_flight(&self) -> usize
pub fn requests_in_flight(&self) -> usize
Count of all requests currently in-flight.
Sourcepub fn pieces_requested(&self) -> usize
pub fn pieces_requested(&self) -> usize
Count of all pieces currently requested from at least one peer.