pub struct PieceTracker { /* private fields */ }Expand description
Keeps track of missing pieces (as opposed to blocks) and their owners.
Implementations
Sourceimpl PieceTracker
impl PieceTracker
pub fn new(piece_count: usize) -> Self
Sourcepub fn missing_pieces_rarest_first(&self) -> impl Iterator<Item = usize> + '_
pub fn missing_pieces_rarest_first(&self) -> impl Iterator<Item = usize> + '_
Get an iterator over the not-yet-downloaded pieces, ordered by the number of peers that own each piece, such that pieces with fewest owners are yielded first.
Sourcepub fn get_piece_owners(
&self,
piece_index: usize,
) -> impl Iterator<Item = &SocketAddr> + Clone
pub fn get_piece_owners( &self, piece_index: usize, ) -> impl Iterator<Item = &SocketAddr> + Clone
Get addresses of all peers that own a particular piece.
Sourcepub fn get_peer_pieces(
&self,
peer: &SocketAddr,
) -> impl Iterator<Item = usize> + Clone + '_
pub fn get_peer_pieces( &self, peer: &SocketAddr, ) -> impl Iterator<Item = usize> + Clone + '_
Get piece indices of all pieces owned by a particular peer.
Sourcepub fn has_peer_piece(&self, peer: &SocketAddr, piece_index: usize) -> bool
pub fn has_peer_piece(&self, peer: &SocketAddr, piece_index: usize) -> bool
Check if peer ownes piece_index.
Sourcepub fn add_single_record(
&mut self,
piece_owner: &SocketAddr,
piece_index: usize,
) -> bool
pub fn add_single_record( &mut self, piece_owner: &SocketAddr, piece_index: usize, ) -> bool
Record that piece_owner owns piece_index.
Sourcepub fn add_bitfield_record(&mut self, peer: &SocketAddr, bitfield: &Bitfield)
pub fn add_bitfield_record(&mut self, peer: &SocketAddr, bitfield: &Bitfield)
Record that peer owns pieces represented by the bitfield. This won’t invalidate any
previous records for the same peer, i.e. it will never remove pieces.
Sourcepub fn forget_peer(&mut self, peer: &SocketAddr)
pub fn forget_peer(&mut self, peer: &SocketAddr)
Erase all records pertaining to the specified peer.
Sourcepub fn forget_piece(&mut self, piece_index: usize)
pub fn forget_piece(&mut self, piece_index: usize)
Erase all records pertaining to the specified piece.