PrefixedStream

Struct PrefixedStream 

pub struct PrefixedStream<T: Buf, S> { /* private fields */ }
A wrapper around an AsyncRead that first returns the bytes from an initial buffer T, and then delegates to the wrapped stream S. Similar to Chain, but also implements AsyncWrite and SplitStream if S does.

Implementations

Source

impl<T: Buf, S> PrefixedStream<T, S>

pub fn new(prefix: T, stream: S) -> Self

Creates a new PrefixedStream that wraps the given initial buffer and stream.

pub fn into_parts(self) -> (T, S)

Consumes the PrefixedStream, returning the prefix buffer and the wrapped stream.